@@ -4,6 +4,7 @@
  *
  * Copyright (C)
  *   2002 - 2012  Arnaud Quette <arnaud.quette@free.fr>
+ *   2022 - 2024  Jim Klimov <jimklimov+nut@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +30,7 @@
 #include "config.h"
 
 #ifdef HAVE_GETOPT_LONG
-#include <getopt.h>
+# include <getopt.h>
 #endif
 
 
@@ -38,36 +39,36 @@
 \*******************************************************************************/
 void AddRcKey(rckeys *key, const char *label, int type, void *var) {
 
-  if(label != NULL) {
-/*    key->label = (char *)xmalloc(strlen(label) + 1); */
-    key->label = (char *)malloc(strlen(label) + 1);
-    strcpy(key->label, label);
-  }
-  else
-    key->label = NULL;
+	if (label != NULL) {
+/*		key->label = (char *)xmalloc(strlen(label) + 1); */
+		key->label = (char *)malloc(strlen(label) + 1);
+		strcpy(key->label, label);
+	}
+	else
+		key->label = NULL;
 
-  key->type = type;
+	key->type = type;
 
-  switch(type) {
-  case TYPE_STRING :
-    key->var.str = (char *)var;
-    break;
-  case TYPE_BOOL: 
-  case TYPE_INT:
-    key->var.integer = (int *)var;
-    break;
-  case TYPE_FLOAT:
-    key->var.floater = (float *)var;
-    break;
-  case TYPE_NULL:
-    break;
-  }
+	switch(type) {
+	case TYPE_STRING :
+		key->var.str = (char *)var;
+		break;
+	case TYPE_BOOL:
+	case TYPE_INT:
+		key->var.integer = (int *)var;
+		break;
+	case TYPE_FLOAT:
+		key->var.floater = (float *)var;
+		break;
+	case TYPE_NULL:
+		break;
+	}
 }
 
 /* TODO : void FreeRcKeys(rckeys *key)*/
 
 /*******************************************************************************\
-|* ParseRCFile		  						        |
+|* ParseRCFile                                                                  |
 \*******************************************************************************/
 void ParseRCFile(const char *filename, rckeys *keys)
 {
@@ -76,7 +77,7 @@ void ParseRCFile(const char *filename, rckeys *keys)
 	char	*tokens = " =\t\n#";
 	FILE	*fp;
 	int	key;
-	
+
 	fp = fopen(filename, "r");
 	if (fp) {
 #ifdef DEBUG
@@ -95,21 +96,22 @@ void ParseRCFile(const char *filename, rckeys *keys)
 						tmp = strpbrk(p, tokens);
 						*tmp = '\0';
 #ifdef DEBUG
-						printf("Parameter -> %s%s\tValue -> %s\n", keys[key].label, 
+						printf("Parameter -> %s%s\tValue -> %s\n", keys[key].label,
 							((strlen(keys[key].label) <12)?"\t\t":"\t"), p);
 #endif
 						switch(keys[key].type)
 						{
 							case TYPE_STRING:
-								/*			if (keys[key].var.str !=NULL)
-								free(keys[key].var.str);
-								keys[key].var.str = (char *)xmalloc(strlen(p) + 1);				
-								strncpy(keys[key].var.str, p, strlen(p)); 
+								/*
+								if (keys[key].var.str !=NULL)
+									free(keys[key].var.str);
+								keys[key].var.str = (char *)xmalloc(strlen(p) + 1);
+								strncpy(keys[key].var.str, p, strlen(p));
 								*/
-								if(!strcmp(keys[key].label, "UPS"))
+								if (!strcmp(keys[key].label, "UPS"))
 									AddHost(p);
 								break;
-							case TYPE_BOOL:    
+							case TYPE_BOOL:
 								if (!strncmp(p, "on", 2))
 									*keys[key].var.bool = 1;
 								else
@@ -133,7 +135,7 @@ void ParseRCFile(const char *filename, rckeys *keys)
 }
 
 /*******************************************************************************\
-|* LoadRCFile		  						        |
+|* LoadRCFile                                                                   |
 \*******************************************************************************/
 void LoadRCFile(rckeys *keys)
 {
@@ -141,23 +143,27 @@ void LoadRCFile(rckeys *keys)
 	char	*p;
 
 #ifdef DEBUG
-    printf("Loading rc files\n");
+	printf("Loading rc files\n");
 #endif
 
 	ParseRCFile(MAINRC_FILE, keys);
-	
+
 	p = getenv("HOME");
 	sprintf(home_file, "%s/%s", p, RC_FILE);
 	ParseRCFile(home_file, keys);
 }
 
 /*******************************************************************************\
-|* ParseCMDLine()  
+|* ParseCMDLine()
 \*******************************************************************************/
 void ParseCMDLine(int argc, char *argv[])
 {
-	char *cmdline, *p;
-	int  i, c;
+	char	*p;
+	int	c;
+#if 0
+	char	*cmdline;
+	int	i;
+#endif
 
 #ifdef HAVE_GETOPT_LONG
 		static struct option long_options[] =
@@ -176,22 +182,22 @@ void ParseCMDLine(int argc, char *argv[])
 			{"windowed",no_argument,NULL,'w'},
 			{0, 0, 0, 0}
 		};
-		
+
 		#define GETOPTFUNC(x,y,z) getopt_long(x,y,"-" z, long_options, NULL)
 		#define GETOPTENDCHAR -1
-#else   /* ! HAVE_GETOPT_LONG */
+#else	/* ! HAVE_GETOPT_LONG */
 		#define GETOPTFUNC(x,y,z) getopt(x,y,z)
 		#define GETOPTENDCHAR EOF
-#endif
+#endif	/* ! HAVE_GETOPT_LONG */
 
 	while(1)
 	{
-	  if ((c=GETOPTFUNC (argc, argv, "A:b:B:C:d:hlL:U:vVw")) == GETOPTENDCHAR)
+		if ((c=GETOPTFUNC (argc, argv, "A:b:B:C:d:hlL:U:vVw")) == GETOPTENDCHAR)
 			break;
 
 		switch (c)
 		{
-			case 'A': 
+			case 'A':
 				Alert = 1;
 				printf ("option A : valeur %s\n", optarg);
 				p = strchr(optarg, ',');
@@ -202,22 +208,22 @@ void ParseCMDLine(int argc, char *argv[])
 				printf ("option A : valeur LAlertRate = %f(%s), CAlertRate = %f(%s)\n",
 					LAlertRate, optarg, CAlertRate, (p+1));
 				break;
-			case 'b': 
+			case 'b':
 				BlinkRate = atof(optarg);
 				break;
-			case 'C': 
+			case 'C':
 				CriticalLevel = atoi(optarg);
 				break;
-			case 'L': 
+			case 'L':
 				LowLevel = atoi(optarg);
 				break;
-			case 'l': 
+			case 'l':
 				UseLowColorPixmap = 1;
 				break;
-			case 'V': 
+			case 'V':
 				Verbose = 1;
 				break;
-			case 'v':   
+			case 'v':
 				printf("\nThis is wmnut version: %s\n", VERSION);
 				printf("\nCopyright 2001-2016 Arnaud Quette <%s>\n", PACKAGE_BUGREPORT);
 				printf("\nComplete documentation for WMNUT should be found on this system using\n");
@@ -227,22 +233,22 @@ void ParseCMDLine(int argc, char *argv[])
 				 * http://web.archive.org/web/20111003175836/http://wmnut.mgeops.org/
 				 */
 				exit(1);
-			case 'w': 
+			case 'w':
 				WithDrawn = 0; /* not in default withdrawn mode, so in windowed mode */
 				break;
-			case 'B': 
+			case 'B':
 				Beep = 1;
 				Volume = atoi(optarg);
 				break;
-			case 'U': 
+			case 'U':
 				AddHost(optarg);
 				break;
 			case 'h':
-			default:  
+			default:
 				printf("\n%s version: %s\n", PACKAGE, VERSION);
 				printf("Usage: %s [arguments]\n\n", PACKAGE_NAME);
 				printf("-A <T1,T2>\tSend messages to users terminals when Low and critical.\n");
-				printf("             \tT1 is seconds between messages when Low.\n"); 
+				printf("             \tT1 is seconds between messages when Low.\n");
 				printf("             \tT2 is seconds between messages when Critical.\n");
 				printf("-b <BlinkRate>\tBlink rate for red LED. (0 for no blinking.)\n");
 				printf("-B <Volume>\tBeep at Critical Level with Volume (between -100%% to 100%%).\n");
